/* vi:set ts=8 sts=0 sw=8:
 * $Id: main.c,v 1.8 2000/05/19 16:33:28 kahn Exp kahn $
 *
 * Copyright (C) 2000 Andy C. Kahn
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gnome.h>
#include <glade/glade.h>

#include "main.h"
#include "win.h"


struct ef_app_s {
	GSList *        win;            /* list of windows */
	GtkWidget *     prefs;          /* preferences dialog */
	GtkWidget *     about;          /* about dialog */
	GtkWidget *     winlist;        /* window list dialog */
};
typedef struct ef_app_s ef_app_t;

static ef_app_t ef_app;

int
main(int argc, char *argv[])
{
	win_t *w;

#ifdef ENABLE_NLS
	bindtextdomain(PACKAGE, PACKAGE_LOCALE_DIR);
	textdomain(PACKAGE);
#endif
	gnome_init("gnome-find", VERSION, argc, argv);
	glade_gnome_init();

	w = win_new();
	ef_win_add(w);

	gtk_main();
#ifdef ENABLE_DEBUG
	printf("bye!\n");
#endif
	return 0;
} /* main */


void
ef_quit_cb(GtkWidget *wgt, gpointer cbdata)
{
	GSList *wp;
	win_t *w;

	/*
	 * Look through all the windows and mark them for closing.  If any of
	 * them have a search in progress, don't close that window right away.
	 * Instead, mark that window for closing, and close it once we abort
	 * the search.
	 *
	 * Note that we could have just done an exit() here, but that's kind
	 * of abrupt and if we ever create temporary files or other things, it
	 * will require cleanup.
	 */
	wp = ef_app.win;
	while (wp) {
		w = (win_t *)wp->data;
		wp = wp->next;

		if (w->is_searching) {
			w->close_window = TRUE;
			w->stop_search = TRUE;
		} else
			ef_win_remove(w);
	}
} /* ef_quit_cb */


void
ef_win_add(win_t *w)
{
	ef_app.win = g_slist_append(ef_app.win, w);
} /* ef_win_add */


void
ef_win_remove(win_t *w)
{
	GSList *wp;

	gtk_timeout_remove(w->timeout_id);
	wp = g_slist_find(ef_app.win, w);
	ef_app.win = g_slist_remove_link(ef_app.win, wp);
	g_free(w->mainwgts);
	g_free(w->reswgts);
	g_free(w->advwgts);
	g_free(w->filewgts);
	g_free(w->dirwgts);
	g_free(w->lastmsg);
	g_free(w);
	g_slist_free_1(wp);

	if (g_slist_length(ef_app.win) < 1)
		gtk_main_quit();
} /* ef_win_remove */


/* the end */
